All Classes and Interfaces
Class
Description
AppHelper.Builder to build AppHelper.The
C2Helper provides means to manage launching and connecting to a
C2 server.AbstractBuilderCli to build
C2Helper instances.
The
CliHelper provides means to support CLI command line argument
parsing.E.g. using the CliHelper you easily can create configuration
files ("--init" or "--init path/to/your/config") from a template (found in
"src/main/resources"), print a help text ("--help"), show system information
("--sysinfo") for support issues, regard being more verbose ("--verbose") or
more quiet ("--quiet"), load a configuration from a specific location
("--config path/to/your/config"), all given that your command line syntax
given uses the according predefined args syntax Term elements such as
HelpFlag, VerboseFlag, QuietFlag, InitFlag,
SysInfoFlag, DebugFlag or ConfigOption (and the
like).The
CliHelper.ArgsParseMessageMode determines the details level for
messages printed out upon parse failure of the command line arguments.CliHelper.Builder to build CliHelper.This interface defines the base functionality for any derived command line
interface (CLI) related archetype helper class.
The
CtxAppHelper is a stripped down CtxHelper intended to be
used by GUI applications which must(!)CtxAppHelper.Builder to build CtxAppHelper.The
CtxHelper enables harnessing the CliApplicationProperties
alongside the CliApplicationProperties profile support (as of
ProfileProperties.getRuntimeProfiles()) by automatically placing an
accordingly configured CliApplicationProperties instance into the
container and enabling it for injection.CtxHelper.Builder to build CliHelper.