All Classes and Interfaces

Class
Description
The AppHelper is a stripped down CliHelper intended to be used by GUI applications which must(!)
The C2Helper provides means to manage launching and connecting to a C2 server.
AbstractBuilderCli to build C2Helper instances.
The CliHelper provides means to support CLI command line argument parsing.E.g. using the CliHelper you easily can create configuration files ("--init" or "--init path/to/your/config") from a template (found in "src/main/resources"), print a help text ("--help"), show system information ("--sysinfo") for support issues, regard being more verbose ("--verbose") or more quiet ("--quiet"), load a configuration from a specific location ("--config path/to/your/config"), all given that your command line syntax given uses the according predefined args syntax Term elements such as HelpFlag, VerboseFlag, QuietFlag, InitFlag, SysInfoFlag, DebugFlag or ConfigOption (and the like).
The CliHelper.ArgsParseMessageMode determines the details level for messages printed out upon parse failure of the command line arguments.
The CtxAppHelper is a stripped down CtxHelper intended to be used by GUI applications which must(!)
The CtxHelper enables harnessing the ApplicationProperties alongside the ApplicationProperties profile support (as of ProfileProperties.getRuntimeProfiles()) by automatically placing an accordingly configured ApplicationProperties instance into the container and enabling it for injection.